@@ -6,27 +6,22 @@ import random
 import shutil
 import secrets
 import string
+import time
 import uuid
 
 import pandas as pd
+import pyperclip
 
 from .cmd_reader import reader
 from .encryption import Rosetta
 from .storage import DataBase
 from .settings import Settings
-
-HERE = os.path.dirname(os.path.abspath(__file__))
-PRINT_FORMAT_SETTINGS = ['df', 'v', 'h']
-TABLE_HEADERS = [' ', 'SOURCE', 'USERNAME', 'PASSWORD']
-DEFAULT_PASSWORD_LENGTH = 42
-MAX_PASSWORD_ITERATIONS = 500
+from .constants import *
 
 def main():
     cmd, args, kwargs = reader()
     if cmd in {'-i', '--interactive'}:
         Session.interactive()
-    elif cmd in {'-h', '--help'}:
-        _help_menu()
     else:
         Session.static(cmd, args, kwargs)
 
@@ -71,8 +66,10 @@ def _archive(*args, **kwargs):
     settings.archive(archive_file)
     settings._write()
 
-def _confirm():
-    confirm = input('are you sure? This can not be undone. [y/n]\n$ ')
+def _confirm(message="are you sure? This can not be undone."):
+    if not message.endswith(" [y/n]\n$ "):
+        message += " [y/n]\n$ "
+    confirm = input(message)
     if confirm == 'y':
         return True
     return False
@@ -90,6 +87,43 @@ def _consume_csv(self, *args, **kwargs):
     self.db.update_db(df.applymap(self.rosetta.encrypt))
     self.df = df
 
+def _copy_to_clipboard(self, df, cp, format_option, **kwargs):
+    index = df.index.values.tolist()
+    if len(index) > 1:
+        print(
+            "search parameters are ambiguous. "
+            "Consider using the index when copying.\n"
+        )
+        if _confirm("display results of the search?"):
+            _print_df(df, format_option)
+    else:
+        cache_time = kwargs.get("-t") or kwargs.get("--time") or self.settings["cache_time"]
+        mapping = {
+            "s": "source",
+            "u": "username",
+            "p": "password"
+        }
+        if 'd' in cp:
+            _print_df(df, format_option)
+        cp = cp.replace("d", "")
+        for item in cp:
+            pyperclip.copy(df.loc[index[0], mapping[item]])
+            if cache_time:
+                for t in reversed(range(int(float(cache_time)))):
+                    print(
+                        f"{mapping[item]} copied to clipboard."
+                        " {:>5} seconds till next...".format(t), 
+                        end='\r'
+                    )
+                    time.sleep(1)
+                print("")
+            else:
+                input(
+                    f"{mapping[item]} copied to clipboard. "
+                    f"Press Enter to continue...\n"
+                )
+        pyperclip.copy("")
+
 def _dump_to_csv(self, *args, **kwargs):
     path = args[0] or kwargs.get('-p') or kwargs.get('--path') or input(
         '\nplease enter a filepath to copy the vlt db to:\n$ '
@@ -103,7 +137,11 @@ def _dump_to_csv(self, *args, **kwargs):
     df.to_csv(path, index=False)
 
 def _edit_db(self, *args, **kwargs):
-    index = kwargs.get('-i') or kwargs.get('--index') or _get_index(self, "edit")
+    index = (
+        kwargs.get('-i') 
+        or kwargs.get('--index') 
+        or _get_index(self, "edit")
+    )
     index = int(index)
     df = self.db.get().applymap(self.rosetta.decrypt)
     source = kwargs.get('-s') or kwargs.get('--source')
@@ -145,7 +183,8 @@ def _get_from_db(self, *args, **kwargs):
 
     if args == () and not any(
         c in kwargs.keys() for c in (
-            '-i', '--index', '-s', '--source', '-u', '--username', '-p', '--password'
+            '-i', '--index', '-s', '--source', 
+            '-u', '--username', '-p', '--password'
         )
     ):
         args, kwargs = _request_search_terms()
@@ -173,7 +212,16 @@ def _get_from_db(self, *args, **kwargs):
         df = df.loc[df['username'] == username]
     if password:
         df = df.loc[df['password'] == password]
-    _print_df(df, format_option)
+    
+    cp = (
+        kwargs.get('-cp') 
+        or kwargs.get("--clip") 
+        or self.settings['clipboard_settings']
+    )
+    if cp:
+        _copy_to_clipboard(self, df, cp, format_option, **kwargs)
+    else:
+        _print_df(df, format_option)
 
 def _get_index(self, action):
     index = input(
@@ -185,10 +233,6 @@ def _get_index(self, action):
         index = _get_index(self, action)
     return index
 
-def _help_menu():
-    with open(os.path.join(HERE, 'help_text.txt'), 'r') as f:
-        print(f.read())
-
 def _link_db(*args, **kwargs):
     if args:
         path = args[0]
@@ -233,6 +277,8 @@ def _list_db(*args, **kwargs):
             print('None')
     elif "name" in args:
         print("    -  " + settings["name"])
+    elif "cmd" in args:
+        print(json.dumps(COMMAND_MAPPING, indent=2, sort_keys=True))
     else:
         print(json.dumps(settings.settings, indent=2, sort_keys=True))
 
