@@ -1,5 +1,7 @@
 import sys
 
+from .help_menu import HelpMenu
+
 def simple_isnan(item):
     try:
         float(item)
@@ -7,9 +9,18 @@ def simple_isnan(item):
     except ValueError:
         return True
 
+def _get_help(cmd=""):
+    help_menu = HelpMenu()
+    help_menu.get(cmd)
+    sys.exit()
+
 def reader():
     cmd = sys.argv[1]
     args = sys.argv[2::]
+    if cmd in ("-h", "--help"):
+        return _get_help()
+    elif any(h in args for h in ("-h", "--help")):
+        return _get_help(cmd)
     kwargs = {}
     kwarg_keys = reversed([
         index for index, item in enumerate(args) 
